@@ -1,10 +1,18 @@
 import logging
 import re
 from abc import abstractmethod
-from collections.abc import Iterable
-from re import Match, Pattern
 from types import TracebackType
-from typing import Any, Generic, List, TypeVar, Union  # noqa: PEA001
+from typing import (  # noqa: PEA001
+    Any,
+    Generic,
+    Iterable,
+    List,
+    Match,
+    Pattern,
+    Type,
+    TypeVar,
+    Union,
+)
 
 from . import util
 from .const import UNDEFINED
@@ -79,7 +87,7 @@ class SelectorList(Generic[T]):
     def __init__(
         self,
         selector_list: List[Selector[T]],
-        origin_selector_class: type[Selector[T]],
+        origin_selector_class: Type[Selector[T]],
         origin_query: str,
     ) -> None:
         self.selector_list = selector_list
@@ -90,7 +98,7 @@ class SelectorList(Generic[T]):
         return self
 
     def __exit__(
-        self, exc_type: type[Exception], exc_value: Exception, traceback: TracebackType
+        self, exc_type: Type[Exception], exc_value: Exception, traceback: TracebackType
     ) -> None:
         pass
 
